@@ -1,12 +1,12 @@
+from __init__ import * #排好顺序start变量覆盖
 from p.__init__ import *
 from p.y import *
 from p.yh import *
 from p.yz import *
-from __init__ import *
 def main():
     A()
     print('\033[1;1m 由于更换颜色太费时费力,所以只加入了部分颜色,请谅解')
-    print('\033[7;36m开始使用时间:\033[0m','\033[7;32m',start,'\nWelcome Users!','\033[0m')
+    print('\033[7;36m本次开始使用时间:\033[0m','\033[7;32m',start,'\nWelcome Users!','\033[0m')
     while True:
         print('\033[1;1m')
         print('=====切换/选择模式，请选择=====\n模式1.计算关于圆的计算(输入1执行)\n模式2.计算关于圆柱的计算(输入2执行)\n模式3.计算关于圆环的计算(输入3执行)\n输入其他数字退出')
